<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Image Resizer with Preloaded Images</title>
    <style>
        body {
            font-family: Arial, sans-serif;
            display: flex;
            justify-content: center;
            align-items: center;
            height: 100vh;
            margin: 0;
            background-color: #eaeaea;
        }

        .container {
            display: flex;
            flex-direction: column;
            gap: 20px;
            background: white;
            padding: 20px;
            border-radius: 8px;
            box-shadow: 0 4px 8px rgba(0, 0, 0, 0.1);
            width: 100%;
            max-width: 1200px;
            
        }

        .column {
            display: flex;
            flex-direction: column;
            align-items: center;
            width: 100%;
        }

        h1 {
            margin-bottom: 20px;
            color: #333;
        }

        .controls {
            display: flex;
            flex-wrap: wrap;
            gap: 10px;
            align-items: center;
            justify-content: center;
            margin-bottom: 20px;
            border:0px solid green;
        }

        .controls > * {
            flex: 1;
            max-width: 120px;
        }

    
        input[type="number"],
        input[type="file"] {
            padding: 10px;
            border: 1px solid #ddd;
            border-radius: 4px;
            width: 100%;
        }

        button {
            padding: 10px 20px;
            cursor: pointer;
            background-color: #86c64d;
            border: none;
            color: white;
            border-radius: 4px;
            transition: background-color 0.3s;
        }

        button:disabled {
            background-color: grey;
            cursor: not-allowed;
        }

        #resizeButton.active {
            background-color: red;
        }

        .image-row {
            display: flex;
            flex-wrap: wrap;
            justify-content: center;
            gap: 10px;
        }

        .thumbnail {
            width: 100%;
            max-width: 300px;
            height: auto;
            border: 1px solid #ddd;
            border-radius: 4px;
            object-fit: cover;
        }

        canvas.thumbnail {
            width: 100%;
            max-width: 300px;
            height: auto;
            border: 1px solid #ddd;
            border-radius: 4px;
        }

        @media (max-width: 768px) {
            .container {
                padding: 10px;
                gap: 10px;
            }

            .controls {
                flex-direction: column;
                align-items: stretch;
            }

            .controls > * {
                max-width: 100%;
                margin-bottom: 10px;
            }

            .controls-row {
                flex-direction: column;
            }

            .image-row {
                flex-direction: column;
                align-items: center;
            }

            .thumbnail {
                max-width: 100%;
            }

            canvas.thumbnail {
                max-width: 100%;
            }
        }
    </style>
    <script src="https://cdnjs.cloudflare.com/ajax/libs/jszip/3.10.1/jszip.min.js"></script>
</head>
<body>
    <div class="container">
        <!-- Column 1: Existing Image Upload Resizer -->
        <div class="column">
            <h1>Aspeed Image Resizer</h1>
         
             
          
            <div class="controls">
            <input type="file" id="uploadImage" accept="image/*">
              
                <input type="number" id="width" placeholder="Width">
              
                <input type="number" id="height" placeholder="Height">
                <button id="resizeButton">Resize</button>
                <button id="downloadButton" disabled>Download</button>
            </div>
            <canvas id="canvas" class="thumbnail"></canvas>
        </div>

        <!-- Column 2: Preloaded Images Resizer -->
        <div class="column">
            <h1>Preloaded Image Resizer</h1>
            <div class="controls">
                
                <input type="number" id="width2" placeholder="Width">
                
                <input type="number" id="height2" placeholder="Height">
                <button id="resizeButton2">Resize</button>
                <button id="downloadButton2" disabled>Download</button>
            </div>

            <div class="image-row">
                <canvas id="canvas2" class="thumbnail"></canvas>
                <canvas id="canvas3" class="thumbnail"></canvas>
            </div>
        </div>
    </div>

    <script>
        // Column 1: Existing Image Resizer
        const uploadImage = document.getElementById('uploadImage');
        const canvas = document.getElementById('canvas');
        const resizeButton = document.getElementById('resizeButton');
        const downloadButton = document.getElementById('downloadButton');
        const widthInput = document.getElementById('width');
        const heightInput = document.getElementById('height');
        const ctx = canvas.getContext('2d');

        let originalImage = new Image();

        uploadImage.addEventListener('change', function (e) {
            const reader = new FileReader();
            reader.onload = function (event) {
                originalImage.onload = function () {
                    widthInput.value = originalImage.width;
                    heightInput.value = originalImage.height;
                    canvas.width = originalImage.width;
                    canvas.height = originalImage.height;
                    ctx.drawImage(originalImage, 0, 0, originalImage.width, originalImage.height);
                    downloadButton.disabled = false;
                };
                originalImage.src = event.target.result;
            };
            reader.readAsDataURL(e.target.files[0]);
        });

        resizeButton.addEventListener('click', function () {
            const width = parseInt(widthInput.value);
            const height = parseInt(heightInput.value);
            canvas.width = width;
            canvas.height = height;
            ctx.drawImage(originalImage, 0, 0, width, height);

            resizeButton.classList.add('active');
        });

        downloadButton.addEventListener('click', function () {
            const link = document.createElement('a');
            link.download = 'resized-image.png';
            link.href = canvas.toDataURL();
            link.click();
        });

        // Column 2: Preloaded Images Resizer
        const canvas2 = document.getElementById('canvas2');
        const canvas3 = document.getElementById('canvas3');
        const ctx2 = canvas2.getContext('2d');
        const ctx3 = canvas3.getContext('2d');
        const widthInput2 = document.getElementById('width2');
        const heightInput2 = document.getElementById('height2');
        const downloadButton2 = document.getElementById('downloadButton2');

        const image1 = new Image();
        const image2 = new Image();

        image1.src = 'image1.jpg';  // Preloaded image 1
        image2.src = 'image2.jpg';  // Preloaded image 2

        image1.onload = function() {
            canvas2.width = image1.width;
            canvas2.height = image1.height;
            ctx2.drawImage(image1, 0, 0);
        };

        image2.onload = function() {
            canvas3.width = image2.width;
            canvas3.height = image2.height;
            ctx3.drawImage(image2, 0, 0);
        };

        document.getElementById('resizeButton2').addEventListener('click', function () {
            const width = parseInt(widthInput2.value);
            const height = parseInt(heightInput2.value);

            // Resize Image 1
            canvas2.width = width;
            canvas2.height = height;
            ctx2.drawImage(image1, 0, 0, width, height);

            // Resize Image 2
            canvas3.width = width;
            canvas3.height = height;
            ctx3.drawImage(image2, 0, 0, width, height);

            downloadButton2.disabled = false;
        });

        downloadButton2.addEventListener('click', function () {
            const zip = new JSZip();
            
            zip.file('resized-image1.png', canvas2.toDataURL('image/png').split(',')[1], { base64: true });
            zip.file('resized-image2.png', canvas3.toDataURL('image/png').split(',')[1], { base64: true });
            
            zip.generateAsync({ type: 'blob' })
                .then(function (content) {
                    const link = document.createElement('a');
                    link.href = URL.createObjectURL(content);
                    link.download = 'resized-images.zip';
                    link.click();
                })
                .catch(function (err) {
                    console.error('Failed to generate ZIP file:', err);
                });
        });
    </script>
</body>
</html>
